==> kdevelop_4.6.0.orig.tar.xz: kdevelop-4.6.0/formatters/astyle/kdevastyle.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=kdevelop
Comment=A plugin for formatting of sourcecode according to a specified set of rules
Comment[bs]=Dodatak za formatiranje izvornog koda prema određenom nizu pravila
Comment[ca]=Un connector per formatar el codi font d'acord a un conjunt especificat de regles
Comment[ca@valencia]=Un connector per formatar el codi font d'acord a un conjunt especificat de regles
Comment[da]=Et plugin til at formatere kildekode ifølge et angivet sæt regler
Comment[de]=Modul zum Formatieren von Quelltext nach bestimmten Vorschriften
Comment[el]=Ένα πρόσθετο για τη μορφοποίηση πηγαίου κώδικα σύμφωνα με καθορισμένους κανόνες
Comment[en_GB]=A plugin for formatting of sourcecode according to a specified set of rules
Comment[es]=Un complemento para formatear código fuente según un conjunto de reglas especificadas
Comment[et]=Plugin lähtekoodi vormindamiseks vastavalt konkreetsetele reeglitele.
Comment[fi]=Liitännäinen lähdekoodin muotoilemiseen määritellyn sääntöjoukon mukaan
Comment[fr]=Un module externe pour le formatage de code source en fonction d'un ensemble précis de règles
Comment[ga]=Breiseán a fhormáidíonn cód foinseach de réir rialacha sonraithe
Comment[gl]=Un engadido para formatar o código fonte segundo un conxunto específico de regras
Comment[hu]=Egy bővítőmodul forráskód formázásához a megadott szabályok alapján.
Comment[it]=Un'estensione per la formattazione del codice sorgente secondo uno specifico insieme di regole
Comment[ja]=指定された規則に従ってソースコードを整形します
Comment[kk]=Келтірілген ереже жиыны бойынша бастапқы кодты пішімдеу плагині
Comment[lv]=Sparudnis pirmkoda formatēšanai atbilstoši dotu noteikumu kopai
Comment[nb]=Et programtillegg for formattering av kildekode i følge et bestemt regelsett
Comment[nds]=En Moduul för't Formateren vun Borntext langs angeven Regeln
Comment[nl]=Een plugin om broncode te formatteren volgens een speciale set regels
Comment[pl]=Wtyczka do formatowania kodu źródłowego zgodnie z podanymi regułami
Comment[pt]=Um 'plugin' de formatação do código-fonte, com base num conjunto de regras definido
Comment[pt_BR]=Um plugin para formatar código-fonte de acordo com um conjunto de regras
Comment[ru]=Расширение для форматирования кода по установленным правилам
Comment[sk]=Modul pre formátovanie zdrojového kódu podľa špecifických pravidiel
Comment[sl]=Vstavek za oblikovanje izvorne kode po določenih pravilih
Comment[sv]=Ett insticksprogram för formatering av källkod enligt en angiven uppsättning regler
Comment[tr]=Belli kurallara göre kaynak kodları biçimlendirmeye yarayan bir eklenti
Comment[ug]=ئەسلى كودنى كۆرسىتىلگەن بىر قاتار قائىدىلەرگە ئاساسەن پىچىدىغان قىستۇرما
Comment[uk]=Додаток для форматування коду у відповідності до вказаного набору правил
Comment[x-test]=xxA plugin for formatting of sourcecode according to a specified set of rulesxx
Comment[zh_CN]=一个根据指定规则设定格式化源代码的插件
Comment[zh_TW]=根據指定的規則排列程式源碼的外掛程式
Name=AStyle Formatter Backend
Name[bs]=AStyle formater pozadine
Name[ca]=Dorsal del formatador AStyle
Name[ca@valencia]=Dorsal del formatador AStyle
Name[da]=AStyle-backend til formatering
Name[de]=AStyle-Formatierer
Name[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου AStyle
Name[en_GB]=AStyle Formatter Backend
Name[es]=Motor del formateador AStyle
Name[et]=AStyle'i vormindamise taustaprogramm
Name[fi]=AStyle-muotoilijataustaohjelma
Name[fr]=Moteur de formatage pour AStyle
Name[gl]=Infraestrutura de formatación do AStyle
Name[hu]=AStyle formázó háttérprogram
Name[it]=Backend formattatore AStyle
Name[ja]=AStyle フォーマッタのバックエンド
Name[kk]=AStyle пішімдегіш тетігі
Name[km]=កម្មវិធី​ខាងក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ AStyle​
Name[nb]=AStyle bakgrunnsmotor for formattering
Name[nds]=AStyle-Formateerhülpprogramm
Name[nl]=Backend voor AStyle formatteerprogramma
Name[pl]=Silnik formatowania AStyle
Name[pt]=Infra-Estrutura de Formatação do AStyle
Name[pt_BR]=Formatador AStyle 
Name[ru]=Механизм форматирования кода AStyle
Name[sk]=Backend formátovača AStyle
Name[sl]=Zaledje oblikovalnika AStyle
Name[sv]=Astyle-formateringsgränssnitt
Name[tr]=Astyle Biçimleyici Arka Ucu
Name[ug]=AStyle پىچقۇچنىڭ ئارقا ئۇچى
Name[uk]=Сервер форматування AStyle
Name[x-test]=xxAStyle Formatter Backendxx
Name[zh_CN]=AStyle 格式化器后端
Name[zh_TW]=AStyle 格式器後端介面
GenericName=Formatter Backend
GenericName[bs]=Formater pozadine
GenericName[ca]=Dorsal del formatador
GenericName[ca@valencia]=Dorsal del formatador
GenericName[da]=Backend til formatering
GenericName[de]=Formatierer
GenericName[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου
GenericName[en_GB]=Formatter Backend
GenericName[es]=Motor del formateador
GenericName[et]=Vormindamise taustaprogramm
GenericName[fi]=Muotoilijan taustaohjelma
GenericName[fr]=Moteur de formatage
GenericName[gl]=Infraestrutura de formato
GenericName[hu]=Formázó háttérprogram
GenericName[it]=Backend formattatore
GenericName[ja]=フォーマッタのバックエンド
GenericName[kk]=Пішімдегіш тетігі
GenericName[km]=កម្មវិធី​ខាង​ក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ
GenericName[nb]=Bakgrunnsmotor for formattering
GenericName[nds]=Formateerhülpprogramm
GenericName[nl]=Formatteer-backend
GenericName[pl]=Silnik formatowania
GenericName[pt]=Infra-Estrutura de Formatação
GenericName[pt_BR]=Formatador
GenericName[ru]=Механизм форматирования исходного кода
GenericName[sk]=Backend formátovača
GenericName[sl]=Zaledje oblikovalnika
GenericName[sv]=Formateringsgränssnitt
GenericName[tr]=Biçimleyici Arka Ucu
GenericName[ug]=پىچقۇچنىڭ ئارقا ئۇچى
GenericName[uk]=Сервер форматування
GenericName[x-test]=xxFormatter Backendxx
GenericName[zh_CN]=格式化器后端
GenericName[zh_TW]=格式器後端介面

ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevastyle
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevastyle
X-KDE-PluginInfo-Author=Cedric Pasteur, Matthias Hölzer-Klüpfel
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ISourceFormatter
X-KDevelop-SupportedMimeTypes=text/x-c++src,text/x-chdr,text/x-c++hdr,text/x-csrc,text/x-java,text/x-csharp
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn

==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/formatters/astyle/kdevastyle.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=kdevelop
Comment=A plugin for formatting of sourcecode according to a specified set of rules
Comment[bs]=Dodatak za formatiranje izvornog koda prema određenom nizu pravila
Comment[ca]=Un connector per formatar el codi font d'acord a un conjunt especificat de regles
Comment[ca@valencia]=Un connector per formatar el codi font d'acord a un conjunt especificat de regles
Comment[da]=Et plugin til at formatere kildekode ifølge et angivet sæt regler
Comment[de]=Modul zum Formatieren von Quelltext nach bestimmten Vorschriften
Comment[el]=Ένα πρόσθετο για τη μορφοποίηση πηγαίου κώδικα σύμφωνα με καθορισμένους κανόνες
Comment[en_GB]=A plugin for formatting of sourcecode according to a specified set of rules
Comment[es]=Un complemento para formatear código fuente según un conjunto de reglas especificadas
Comment[et]=Plugin lähtekoodi vormindamiseks vastavalt konkreetsetele reeglitele.
Comment[fi]=Liitännäinen lähdekoodin muotoilemiseen määritellyn sääntöjoukon mukaan
Comment[fr]=Un module externe pour le formatage de code source en fonction d'un ensemble précis de règles
Comment[ga]=Breiseán a fhormáidíonn cód foinseach de réir rialacha sonraithe
Comment[gl]=Un engadido para formatar o código fonte segundo un conxunto específico de regras
Comment[hu]=Egy bővítőmodul forráskód formázásához a megadott szabályok alapján.
Comment[it]=Un'estensione per la formattazione del codice sorgente secondo uno specifico insieme di regole
Comment[ja]=指定された規則に従ってソースコードを整形します
Comment[kk]=Келтірілген ереже жиыны бойынша бастапқы кодты пішімдеу плагині
Comment[lv]=Sparudnis pirmkoda formatēšanai atbilstoši dotu noteikumu kopai
Comment[nb]=Et programtillegg for formattering av kildekode i følge et bestemt regelsett
Comment[nds]=En Moduul för't Formateren vun Borntext langs angeven Regeln
Comment[nl]=Een plugin om broncode te formatteren volgens een speciale set regels
Comment[pl]=Wtyczka do formatowania kodu źródłowego zgodnie z podanymi regułami
Comment[pt]=Um 'plugin' de formatação do código-fonte, com base num conjunto de regras definido
Comment[pt_BR]=Um plugin para formatar código-fonte de acordo com um conjunto de regras
Comment[ru]=Расширение для форматирования кода по установленным правилам
Comment[sk]=Modul pre formátovanie zdrojového kódu podľa špecifických pravidiel
Comment[sl]=Vstavek za oblikovanje izvorne kode po določenih pravilih
Comment[sv]=Ett insticksprogram för formatering av källkod enligt en angiven uppsättning regler
Comment[tr]=Belli kurallara göre kaynak kodları biçimlendirmeye yarayan bir eklenti
Comment[ug]=ئەسلى كودنى كۆرسىتىلگەن بىر قاتار قائىدىلەرگە ئاساسەن پىچىدىغان قىستۇرما
Comment[uk]=Додаток для форматування коду у відповідності до вказаного набору правил
Comment[x-test]=xxA plugin for formatting of sourcecode according to a specified set of rulesxx
Comment[zh_CN]=一个根据指定规则设定格式化源代码的插件
Comment[zh_TW]=根據指定的規則排列程式源碼的外掛程式
Name=AStyle Formatter Backend
Name[bs]=AStyle formater pozadine
Name[ca]=Dorsal del formatador AStyle
Name[ca@valencia]=Dorsal del formatador AStyle
Name[da]=AStyle-backend til formatering
Name[de]=AStyle-Formatierer
Name[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου AStyle
Name[en_GB]=AStyle Formatter Backend
Name[es]=Motor del formateador AStyle
Name[et]=AStyle'i vormindamise taustaprogramm
Name[fi]=AStyle-muotoilijataustaohjelma
Name[fr]=Moteur de formatage pour AStyle
Name[gl]=Infraestrutura de formatación do AStyle
Name[hu]=AStyle formázó háttérprogram
Name[it]=Backend formattatore AStyle
Name[ja]=AStyle フォーマッタのバックエンド
Name[kk]=AStyle пішімдегіш тетігі
Name[km]=កម្មវិធី​ខាងក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ AStyle​
Name[nb]=AStyle bakgrunnsmotor for formattering
Name[nds]=AStyle-Formateerhülpprogramm
Name[nl]=Backend voor AStyle formatteerprogramma
Name[pl]=Silnik formatowania AStyle
Name[pt]=Infra-Estrutura de Formatação do AStyle
Name[pt_BR]=Infraestrutura de formatação do AStyle
Name[ru]=Механизм форматирования кода AStyle
Name[sk]=Backend formátovača AStyle
Name[sl]=Zaledje oblikovalnika AStyle
Name[sv]=Astyle-formateringsgränssnitt
Name[tr]=Astyle Biçimleyici Arka Ucu
Name[ug]=AStyle پىچقۇچنىڭ ئارقا ئۇچى
Name[uk]=Сервер форматування AStyle
Name[x-test]=xxAStyle Formatter Backendxx
Name[zh_CN]=AStyle 格式化器后端
Name[zh_TW]=AStyle 格式器後端介面
GenericName=Formatter Backend
GenericName[bs]=Formater pozadine
GenericName[ca]=Dorsal del formatador
GenericName[ca@valencia]=Dorsal del formatador
GenericName[da]=Backend til formatering
GenericName[de]=Formatierer
GenericName[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου
GenericName[en_GB]=Formatter Backend
GenericName[es]=Motor del formateador
GenericName[et]=Vormindamise taustaprogramm
GenericName[fi]=Muotoilijan taustaohjelma
GenericName[fr]=Moteur de formatage
GenericName[gl]=Infraestrutura de formato
GenericName[hu]=Formázó háttérprogram
GenericName[it]=Backend formattatore
GenericName[ja]=フォーマッタのバックエンド
GenericName[kk]=Пішімдегіш тетігі
GenericName[km]=កម្មវិធី​ខាង​ក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ
GenericName[nb]=Bakgrunnsmotor for formattering
GenericName[nds]=Formateerhülpprogramm
GenericName[nl]=Formatteer-backend
GenericName[pl]=Silnik formatowania
GenericName[pt]=Infra-Estrutura de Formatação
GenericName[pt_BR]=Formatador
GenericName[ru]=Механизм форматирования исходного кода
GenericName[sk]=Backend formátovača
GenericName[sl]=Zaledje oblikovalnika
GenericName[sv]=Formateringsgränssnitt
GenericName[tr]=Biçimleyici Arka Ucu
GenericName[ug]=پىچقۇچنىڭ ئارقا ئۇچى
GenericName[uk]=Сервер форматування
GenericName[x-test]=xxFormatter Backendxx
GenericName[zh_CN]=格式化器后端
GenericName[zh_TW]=格式器後端介面

ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevastyle
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevastyle
X-KDE-PluginInfo-Author=Cedric Pasteur, Matthias Hölzer-Klüpfel
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ISourceFormatter
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn
